@@ -4,7 +4,24 @@ use strict;
 use warnings;
 use Carp 'croak';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
+
+use Alien::ROOT;
+use vars '$Alien';
+BEGIN {
+  $Alien = Alien::ROOT->new;
+  if (not $Alien->installed) {
+    Carp::croak(
+      "Alien::ROOT could not detect an installation of the ROOT library"
+    );
+  } elsif ($Alien->features !~ /\bexplicitlink\b/) {
+    Carp::croak(
+      "The version of ROOT that was found was not built with the"
+      . " --explicitlink option, which is required for SOOT"
+    );
+  }
+  $Alien->setup_environment;
+}
 
 use base 'Exporter';
 use SOOT::Constants;
